@@ -3,6 +3,25 @@
 #
 # Generated  by generateDS.py.
 #
+# Command line options:
+#   ('--no-dates', '')
+#   ('--no-versions', '')
+#   ('--silence', '')
+#   ('--member-specs', 'list')
+#   ('-f', '')
+#   ('-o', 'tests/simpletypes_other2_sup.py')
+#   ('-s', 'tests/simpletypes_other2_sub.py')
+#   ('--super', 'simpletypes_other2_sup')
+#
+# Command line arguments:
+#   tests/simpletypes_other.xsd
+#
+# Command line:
+#   generateDS.py --no-dates --no-versions --silence --member-specs="list" -f -o "tests/simpletypes_other2_sup.py" -s "tests/simpletypes_other2_sub.py" --super="simpletypes_other2_sup" tests/simpletypes_other.xsd
+#
+# Current working directory (os.getcwd()):
+#   generateds
+#
 
 import sys
 
@@ -102,7 +121,7 @@ def parse(inFilename, silence=False):
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'simpleTypeTests'
+        rootTag = 'simpleTypeTestsType'
         rootClass = supermod.simpleTypeTestsType
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
@@ -122,7 +141,7 @@ def parseEtree(inFilename, silence=False):
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'simpleTypeTests'
+        rootTag = 'simpleTypeTestsType'
         rootClass = supermod.simpleTypeTestsType
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
@@ -146,7 +165,7 @@ def parseString(inString, silence=False):
     rootNode = doc.getroot()
     rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
-        rootTag = 'simpleTypeTests'
+        rootTag = 'simpleTypeTestsType'
         rootClass = supermod.simpleTypeTestsType
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
@@ -163,9 +182,9 @@ def parseString(inString, silence=False):
 def parseLiteral(inFilename, silence=False):
     doc = parsexml_(inFilename)
     rootNode = doc.getroot()
-    roots = get_root_tag(rootNode)
-    rootClass = roots[1]
+    rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
+        rootTag = 'simpleTypeTestsType'
         rootClass = supermod.simpleTypeTestsType
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
@@ -174,8 +193,8 @@ def parseLiteral(inFilename, silence=False):
 ##     if not silence:
 ##         sys.stdout.write('#from simpletypes_other2_sup import *\n\n')
 ##         sys.stdout.write('import simpletypes_other2_sup as model_\n\n')
-##         sys.stdout.write('rootObj = model_.simpleTypeTests(\n')
-##         rootObj.exportLiteral(sys.stdout, 0, name_="simpleTypeTests")
+##         sys.stdout.write('rootObj = model_.rootClass(\n')
+##         rootObj.exportLiteral(sys.stdout, 0, name_=rootTag)
 ##         sys.stdout.write(')\n')
     return rootObj
 
