@@ -331,8 +331,8 @@ class GenTest(unittest.TestCase):
         cmd = 'diff %s1_sub.py %s2_sub.py' % (t_, t_, )
         result, err = self.execute(cmd)
         self.check_result(result, err, ())
-        cmdTempl = 'python tests/%s2_sup.py tests/ipo.xml > tests/%s2_out.xml'
-        cmd = cmdTempl % (t_, t_, )
+        cmdTempl = 'python tests/%s2_sup.py tests/%s.xml > tests/%s2_out.xml'
+        cmd = cmdTempl % (t_, t_, t_, )
         result, _ = self.execute(cmd, cwd='..')
         cmd = 'diff %s1_out.xml %s2_out.xml' % (t_, t_, )
         result, err = self.execute(cmd)
@@ -550,6 +550,54 @@ class GenTest(unittest.TestCase):
         result, err = self.execute(cmd)
         self.check_result(result, err, ())
 
+    def test_025_validate_simpletypes(self):
+        cmdTempl = (
+            'python generateDS.py --no-dates --no-versions '
+            '--member-specs=list -f '
+            '-o tests/%s2_sup.py -s tests/%s2_sub.py '
+            '--super=%s2_sup '
+            'tests/%s.xsd'
+        )
+        t_ = 'validate_simpletypes'
+        cmd = cmdTempl % (t_, t_, t_, t_, )
+        result, _ = self.execute(cmd, cwd='..')
+        cmd = 'diff %s1_sup.py %s2_sup.py' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ('sys.stdout.write',))
+        cmd = 'diff %s1_sub.py %s2_sub.py' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ())
+        cmdTempl = (
+            'python tests/%s2_sup.py tests/%s.xml > tests/%s2_out.xml '
+            '2> tests/%s2_warnings.txt'
+        )
+        cmd = cmdTempl % (t_, t_, t_, t_, )
+        result, _ = self.execute(cmd, cwd='..')
+        cmd = 'diff %s1_out.xml %s2_out.xml' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ())
+        cmd = 'diff %s1_warnings.txt %s2_warnings.txt' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ())
+
+    def test_026_reference_simpletype(self):
+        cmdTempl = (
+            'python generateDS.py --no-dates --no-versions '
+            '--silence --member-specs=list -f '
+            '-o tests/%s2_sup.py -s tests/%s2_sub.py '
+            '--super=%s2_sup '
+            'tests/%s.xsd'
+        )
+        t_ = 'reference_simpletype'
+        cmd = cmdTempl % (t_, t_, t_, t_, )
+        result, _ = self.execute(cmd, cwd='..')
+        cmd = 'diff %s1_sup.py %s2_sup.py' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ('sys.stdout.write',))
+        cmd = 'diff %s1_sub.py %s2_sub.py' % (t_, t_, )
+        result, err = self.execute(cmd)
+        self.check_result(result, err, ())
+
     def check_result(self, result, err, ignore_strings):
         self.failUnlessEqual(len(result), 0)
         self.failUnlessEqual(len(err), 0)
